ADC_MEMITEMTYPE AdcAverage(UCHAR ucUnit, UCHAR ucChannel, ADC_MEMITEMTYPE xDataNew, ADC_MEMITEMTYPE xDataOld, bool bValidOld)
{
   // Default action is to just return the new data unprocessed (there is _no_ error return code)
   register LONG ulResult= xDataNew;
   
   // Caution: Average() is called with the previous modified/scaled values for xDataNew _and_ xDataOld
   // Caution: Driver context! Keep code as short and fast as possible! Avoid blocking calls! Avoid floating point!
   
   if (bValidOld)
   {
      if (ucUnit == 0)
      {
         switch (ucChannel)
         {
            case 5:
               // Arithmetic averaging of Scale AD5 (+5VA)
               ulResult= (xDataNew+ xDataOld)/ 2;
               break;
         }
      }
   }
   else
   {
      if (ucUnit == 0)
      {
         switch (ucChannel)
         {
            case 4:
               // NO Arithmetic averaging of Scale AD4 (+VMOT) for faster limit triggering
               ulResult= xDataNew;
               break;                  
         }
      }      
   }
   
   return ((ADC_MEMITEMTYPE)ulResult);
}

ADC_MEMITEMTYPE AdcModify(UCHAR ucUnit, UCHAR ucChannel, ADC_PDCITEMTYPE xDataNew, ADC_MEMITEMTYPE xDataOld, bool bValidOld)
{
   // Default action is to just return the new data unprocessed (there is _no_ error return code)
   register ULONG ulResult= xDataNew;
   
   // Caution: Modify() is called with the previous modified/scaled value for xDataOld _but_ the _raw_ new value for xDataNew
   // Caution: Driver context! Keep code as short and fast as possible! Avoid blocking calls! Avoid floating point!
   
   if (ucUnit == 0)
   {
      switch (ucChannel)
      {
         case 4:
            // Scale AD4 (+VMOT) to 1/100 V
            ulResult= (xDataNew* 32200)/ 10000;
            break;
            
         case 5:
            // Scale AD5 (+5VA) to 1/100 V
            ulResult= (xDataNew* 64500)/ 100000;
            break;
      }
   }
   
   return ((ADC_MEMITEMTYPE)ulResult);
}
